[][src]Trait remote_trait_object::transport::Terminate

pub trait Terminate: Send {
    fn terminate(&self);
}

A switch that can be separately managed by another thread.

This is the only way to wake up a blocking send() or recv() by yourself. (Not by the other end) TransportSend and TransportRecv must be able to provide such a switch that triggers Termination error for its own send() or recv().

Required methods

fn terminate(&self)

Wakes up block on recv() or send()

Loading content...

Implementors

Loading content...